Replaced "re-register" terminology with "reregister".

We sometimes use "re-register" in comments and elsewhere we
use "reregister". We should pick the "reregister" form and
use it consistently.

Review: https://reviews.apache.org/r/65938/


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/a4e9695f
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/a4e9695f
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/a4e9695f

Branch: refs/heads/master
Commit: a4e9695fedf6cc073f4f30896d21adc0e6e9711c
Parents: 66bae08
Author: James Peach <[email protected]>
Authored: Fri Mar 9 11:07:01 2018 -0800
Committer: James Peach <[email protected]>
Committed: Fri Mar 9 11:07:01 2018 -0800

----------------------------------------------------------------------
 CHANGELOG                                       |  28 ++--
 docs/agent-recovery.md                          |   4 +-
 docs/app-framework-development-guide.md         |   4 +-
 docs/configuration/agent.md                     |   4 +-
 docs/configuration/master.md                    |   8 +-
 docs/high-availability-framework-guide.md       |   2 +-
 docs/high-availability.md                       |   2 +-
 docs/maintenance.md                             |   2 +-
 docs/monitoring.md                              |   2 +-
 docs/operator-http-api.md                       |   8 +-
 docs/reconciliation.md                          |   2 +-
 docs/roles.md                                   |   2 +-
 docs/task-state-reasons.md                      |   2 +-
 include/mesos/authorizer/acls.proto             |   2 +-
 include/mesos/executor.hpp                      |   2 +-
 include/mesos/master/master.proto               |   8 +-
 include/mesos/mesos.proto                       |   4 +-
 include/mesos/scheduler.hpp                     |   2 +-
 include/mesos/scheduler/scheduler.proto         |   4 +-
 include/mesos/v1/master/master.proto            |   8 +-
 include/mesos/v1/mesos.proto                    |   4 +-
 ...2013-10-23-slave-recovery-in-apache-mesos.md |   2 +-
 .../blog/2014-06-12-mesos-0-19-0-released.md    |   4 +-
 .../blog/2017-09-18-mesos-1-4-0-released.md     |   2 +-
 ...performance-working-group-progress-report.md |   6 +-
 src/exec/exec.cpp                               |   4 +-
 src/java/src/org/apache/mesos/Executor.java     |   4 +-
 src/java/src/org/apache/mesos/Scheduler.java    |   4 +-
 src/master/allocator/mesos/hierarchical.cpp     |   4 +-
 src/master/constants.hpp                        |   4 +-
 src/master/flags.cpp                            |   8 +-
 src/master/master.cpp                           | 138 +++++++++----------
 src/master/master.hpp                           |  22 +--
 .../src/mesos/executor/proxy_executor.cpp       |   2 +-
 .../interface/src/mesos/interface/__init__.py   |   4 +-
 src/sched/sched.cpp                             |  10 +-
 src/slave/constants.hpp                         |   4 +-
 .../mesos/isolators/filesystem/linux.cpp        |   2 +-
 .../mesos/isolators/filesystem/posix.cpp        |   2 +-
 src/slave/flags.cpp                             |   4 +-
 src/slave/slave.cpp                             |  32 ++---
 src/slave/slave.hpp                             |   2 +-
 src/slave/task_status_update_manager.cpp        |   2 +-
 src/tests/api_tests.cpp                         |   8 +-
 src/tests/authentication_tests.cpp              |   2 +-
 .../docker_containerizer_tests.cpp              |   8 +-
 .../docker_volume_isolator_tests.cpp            |   2 +-
 .../containerizer/memory_pressure_tests.cpp     |   2 +-
 .../containerizer/ports_isolator_tests.cpp      |   8 +-
 src/tests/containerizer/xfs_quota_tests.cpp     |   4 +-
 src/tests/disk_quota_tests.cpp                  |   2 +-
 src/tests/fault_tolerance_tests.cpp             |  22 +--
 src/tests/fetcher_cache_tests.cpp               |   2 +-
 src/tests/gc_tests.cpp                          |   4 +-
 src/tests/master_allocator_tests.cpp            |   4 +-
 src/tests/master_authorization_tests.cpp        |  12 +-
 src/tests/master_slave_reconciliation_tests.cpp |  22 +--
 src/tests/master_tests.cpp                      |  74 +++++-----
 src/tests/oversubscription_tests.cpp            |   4 +-
 src/tests/partition_tests.cpp                   |  18 +--
 src/tests/persistent_volume_tests.cpp           |   2 +-
 src/tests/slave_recovery_tests.cpp              |  52 +++----
 src/tests/slave_tests.cpp                       |  28 ++--
 .../storage_local_resource_provider_tests.cpp   |   2 +-
 src/tests/teardown_tests.cpp                    |   6 +-
 src/tests/upgrade_tests.cpp                     |   4 +-
 66 files changed, 331 insertions(+), 331 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/CHANGELOG
----------------------------------------------------------------------
diff --git a/CHANGELOG b/CHANGELOG
index 20bfe21..c19559d 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -432,11 +432,11 @@ All Resolved Issues:
   * [MESOS-7469] - Add resource provider driver.
   * [MESOS-7491] - Build a CSI client to talk to a CSI plugin.
   * [MESOS-7533] - Add a function stub for resource provider re-registration.
-  * [MESOS-7534] - Notify resource providers if they've been re-registered.
+  * [MESOS-7534] - Notify resource providers if they've been reregistered.
   * [MESOS-7535] - Distinguish between active and inactive resource providers 
in RP Manager.
   * [MESOS-7550] - Publish Local Resource Provider resources in the agent 
before container launch or update.
   * [MESOS-7555] - Add resource provider IDs to the registry.
-  * [MESOS-7557] - Test that resource providers can re-register after agent 
fails over.
+  * [MESOS-7557] - Test that resource providers can reregister after agent 
fails over.
   * [MESOS-7561] - Add storage resource provider specific information in 
ResourceProviderInfo.
   * [MESOS-7578] - Write a proposal to make the I/O Switchboards optional.
   * [MESOS-7594] - Implement 'apply' for resource provider related operations.
@@ -724,7 +724,7 @@ All Resolved Issues:
   * [MESOS-5116] - Add support for accounting only mode in XFS isolator.
   * [MESOS-5417] - define WSTRINGIFY behaviour on Windows
   * [MESOS-6053] - Combine test helpers into one single binary.
-  * [MESOS-6223] - Allow agents to re-register post a host reboot
+  * [MESOS-6223] - Allow agents to reregister post a host reboot
   * [MESOS-6535] - The default executor should support kill policies
   * [MESOS-6549] - Asynchronous dir removal in agent GC
   * [MESOS-6782] - Inherit Environment from parent container when launching 
DEBUG container.
@@ -1134,7 +1134,7 @@ All Resolved Issues:
   * [MESOS-7047] - Update agent for hierarchical roles.
   * [MESOS-7048] - Remove adjustment code within Resources::apply.
   * [MESOS-7061] - Re-persist tasks/executors with allocation info during 
agent recovery.
-  * [MESOS-7063] - Add a test for a MULTI_ROLE master re-registering an old 
agent.
+  * [MESOS-7063] - Add a test for a MULTI_ROLE master reregistering an old 
agent.
   * [MESOS-7269] - Migrate setting in config.py to a TOML file.
   * [MESOS-7282] - Create a table abstraction for the Mesos CLI.
   * [MESOS-7320] - Remove deprecated ACL `ShutdownFramework`.
@@ -1300,7 +1300,7 @@ Additional API Changes:
     the master might now mark an agent unreachable that would previously
     have been able to eventually recover successfully.
 
-  * [MESOS-6419] - When a framework re-registers after master failover,
+  * [MESOS-6419] - When a framework reregisters after master failover,
     it is only allowed to change certain fields in its FrameworkInfo.
     For example, changing "failover_timeout" is allowed, but changing
     "role" is not. In previous Mesos releases, the same restrictions on
@@ -1442,7 +1442,7 @@ All Issues:
     * [MESOS-6588] - LinuxRootfs misses required files
     * [MESOS-6597] - Include v1 Operator API protos in generated JAR and 
python packages.
     * [MESOS-6598] - Broken Link Framework Development Page
-    * [MESOS-6602] - Shutdown completed frameworks when unreachable agent 
re-registers
+    * [MESOS-6602] - Shutdown completed frameworks when unreachable agent 
reregisters
     * [MESOS-6604] - Uninitialized member ObjectApprover::weight_info.
     * [MESOS-6606] - Reject optimized builds with libcxx before 3.9
     * [MESOS-6618] - Some tests use hardcoded port numbers.
@@ -2525,7 +2525,7 @@ All Issues:
     * [MESOS-4658] - process::Connection can lead to process::wait deadlock
     * [MESOS-4662] - PortMapping network isolator should not assume 
BIND_MOUNT_ROOT is a realpath.
     * [MESOS-4672] - Implement aufs based provisioner backend.
-    * [MESOS-4673] - Agent fails to shutdown after re-registering period 
timed-out.
+    * [MESOS-4673] - Agent fails to shutdown after reregistering period 
timed-out.
     * [MESOS-4680] - HTTP requests to non leading mesos-master redirect to top 
level page
     * [MESOS-4684] - Create base docker image for test suite.
     * [MESOS-4705] - Linux 'perf' parsing logic may fail when OS distribution 
has perf backports.
@@ -5112,7 +5112,7 @@ HTTP endpoint changes:
 
 Deprecations:
   * [MESOS-1219] - Master should disallow completed frameworks from
-    re-registering with same framework id.
+    reregistering with same framework id.
 
   * [MESOS-1695] - "/stats.json" on the slave exposes "registered" value as
     string instead of integer.
@@ -5317,7 +5317,7 @@ All Issues:
   * [MESOS-578] - configure fails on OSX 10.8.4
   * [MESOS-682] - Master should properly consolidate "slaves" and 
"deactivated" maps
   * [MESOS-743] - ReservationAllocatorTest.ResourcesReturned test is flaky
-  * [MESOS-767] - Slave should re-register with completed frameworks/executors
+  * [MESOS-767] - Slave should reregister with completed frameworks/executors
   * [MESOS-779] - mesos python examples use 2 space indent
   * [MESOS-873] - Crash in os::killtree on Mavericks
   * [MESOS-931] - post-review is deprecated.
@@ -5541,7 +5541,7 @@ All Issues:
   * [MESOS-1095] - Build failure on OSX when using gcc-4.7
   * [MESOS-1121] - /usr/include/c++/4.7/type_traits:1834:9: error: no match 
for call to '(std::_Bind<process::Future<process::http::Response> 
(*(std::_Placeholder<1>))(const std::basic_string<char>&)>) ()'
   * [MESOS-1128] - ':' colon in executor work directories is unusual
-  * [MESOS-1135] - A re-registering framework that authenticates with Master 
might not get any offers
+  * [MESOS-1135] - A reregistering framework that authenticates with Master 
might not get any offers
   * [MESOS-1176] - make distcheck fails when enabling c++11
 
 ** Documentation
@@ -5737,7 +5737,7 @@ All Issues:
   * [MESOS-725] - Slave should cleanup meta directory if started in non-strict 
mode and slave info changes.
 
 ** Bug
-  * [MESOS-420] - Master crashes when re-registering framework
+  * [MESOS-420] - Master crashes when reregistering framework
   * [MESOS-488] - The Master incorrectly sends a "Framework failed over" 
message when the scheduler driver retries an initial failover re-registration.
   * [MESOS-641] - Stout killtree / pstree tests fail on Ubuntu 10.04.
   * [MESOS-658] - A framework can be incorrectly removed by the Master.
@@ -5789,7 +5789,7 @@ All Issues:
   * [MESOS-380] - Command Executor doesn't send TASK_KILLED for killed tasks.
   * [MESOS-434] - Process isolator libprocess throws exception
   * [MESOS-449] - CgroupsTests are flaky on Ubuntu
-  * [MESOS-451] - Always update resources for re-registered executors.
+  * [MESOS-451] - Always update resources for reregistered executors.
   * [MESOS-461] - Freezer failure while in FREEZING state.
   * [MESOS-479] - SlaveRecoveryTest/0.CleanupExecutor failure.
   * [MESOS-485] - Latest trunk fails on strict aliasing on CentOS
@@ -5817,7 +5817,7 @@ All Issues:
   * [MESOS-633] - Master should inform a recovered slave about frameworks that 
were completed
   * [MESOS-635] - Master doesn't update the task state when it generates 
TASK_LOST
   * [MESOS-636] - Executors under cgroups isolator die immediately when a 
slave dies if it has a controlling TTY attached
-  * [MESOS-637] - Executor should re-register with the updates in the same 
order as it received them
+  * [MESOS-637] - Executor should reregister with the updates in the same 
order as it received them
   * [MESOS-638] - Slave should not send command executor infos to master when 
it reregisters
   * [MESOS-640] - Duplicate status update with same UUID crashes the slave
   * [MESOS-644] - Slave doesn't correctly handle checkpointed terminal update 
whose ack doesn't reach the executor
@@ -5900,7 +5900,7 @@ All Issues:
   * [MESOS-407] - Google test filter processing is incorrect for the empty 
string.
   * [MESOS-408] - FaultToleranceTest.SlavePartitioned is flaky
   * [MESOS-412] - MasterTest.ShutdownUnregisteredExecutor flaky
-  * [MESOS-423] - A slave asked to shutdown should not re-register with a new 
slave id
+  * [MESOS-423] - A slave asked to shutdown should not reregister with a new 
slave id
   * [MESOS-424] - CgroupsIsolatorTest.BalloonFramework runs forever
   * [MESOS-436] - FaultToleranceTest.SchedulerFailover test is flaky
   * [MESOS-437] - ResourceOffersTest.ResourceOfferWithMultipleSlaves is flaky

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/docs/agent-recovery.md
----------------------------------------------------------------------
diff --git a/docs/agent-recovery.md b/docs/agent-recovery.md
index 8df72cb..98fb6b6 100644
--- a/docs/agent-recovery.md
+++ b/docs/agent-recovery.md
@@ -80,10 +80,10 @@ behavior of a Mesos agent:
       executors and tasks running at an agent die when the agent dies and are
       not recovered.
 
-A restarted agent should re-register with master within a timeout (75 seconds
+A restarted agent should reregister with master within a timeout (75 seconds
 by default: see the `--max_agent_ping_timeouts` and `--agent_ping_timeout`
 [configuration flags](configuration.md)). If the agent takes longer than this
-timeout to re-register, the master shuts down the agent, which in turn will
+timeout to reregister, the master shuts down the agent, which in turn will
 shutdown any live executors/tasks.
 
 Therefore, it is highly recommended to automate the process of restarting an

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/docs/app-framework-development-guide.md
----------------------------------------------------------------------
diff --git a/docs/app-framework-development-guide.md 
b/docs/app-framework-development-guide.md
index e31bffc..835757e 100644
--- a/docs/app-framework-development-guide.md
+++ b/docs/app-framework-development-guide.md
@@ -43,7 +43,7 @@ virtual void registered(
     const MasterInfo& masterInfo);
 
 /*
- * Invoked when the scheduler re-registers with a newly elected Mesos master.
+ * Invoked when the scheduler reregisters with a newly elected Mesos master.
  * This is only called when the scheduler has previously been registered.
  * `MasterInfo` containing the updated information about the elected master
  * is provided as an argument.
@@ -387,7 +387,7 @@ virtual void registered(
     const SlaveInfo& slaveInfo);
 
 /*
- * Invoked when the executor re-registers with a restarted slave.
+ * Invoked when the executor reregisters with a restarted slave.
  */
 virtual void reregistered(ExecutorDriver* driver, const SlaveInfo& slaveInfo);
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/docs/configuration/agent.md
----------------------------------------------------------------------
diff --git a/docs/configuration/agent.md b/docs/configuration/agent.md
index 71e5a86..13e4c55 100644
--- a/docs/configuration/agent.md
+++ b/docs/configuration/agent.md
@@ -689,9 +689,9 @@ shutting it down (e.g., 60secs, 3mins, etc) (default: 1mins)
     --executor_reregistration_timeout=VALUE
   </td>
   <td>
-The timeout within which an executor is expected to re-register after
+The timeout within which an executor is expected to reregister after
 the agent has restarted, before the agent considers it gone and shuts
-it down. Note that currently, the agent will not re-register with the
+it down. Note that currently, the agent will not reregister with the
 master until this timeout has elapsed (see MESOS-7539). (default: 2secs)
   </td>
 </tr>

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/docs/configuration/master.md
----------------------------------------------------------------------
diff --git a/docs/configuration/master.md b/docs/configuration/master.md
index 7b2bb98..6f55ad9 100644
--- a/docs/configuration/master.md
+++ b/docs/configuration/master.md
@@ -162,11 +162,11 @@ checks. The value is of the form <code>(Number of 
agents)/(Duration)</code>.
     --slave_reregister_timeout=VALUE
   </td>
   <td>
-The timeout within which an agent is expected to re-register.
-Agents re-register when they become disconnected from the master
+The timeout within which an agent is expected to reregister.
+Agents reregister when they become disconnected from the master
 or when a new master is elected as the leader. Agents that do not
-re-register within the timeout will be marked unreachable in the
-registry; if/when the agent re-registers with the master, any
+reregister within the timeout will be marked unreachable in the
+registry; if/when the agent reregisters with the master, any
 non-partition-aware tasks running on the agent will be terminated.
 <b>NOTE</b>: This value has to be at least 10mins. (default: 10mins)
   </td>

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/docs/high-availability-framework-guide.md
----------------------------------------------------------------------
diff --git a/docs/high-availability-framework-guide.md 
b/docs/high-availability-framework-guide.md
index f246773..1bf58e1 100644
--- a/docs/high-availability-framework-guide.md
+++ b/docs/high-availability-framework-guide.md
@@ -14,7 +14,7 @@ should consider include:
   example by crashing or by losing network connectivity. If the master has been
   configured to use [high-availability mode](high-availability.md), this will
   result in promoting another Mesos master replica to become the current
-  leader. In this situation, the scheduler should re-register with the new
+  leader. In this situation, the scheduler should reregister with the new
   master and ensure that task state is consistent.
 
 * The host where a framework scheduler is running might fail. To ensure that 
the

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/docs/high-availability.md
----------------------------------------------------------------------
diff --git a/docs/high-availability.md b/docs/high-availability.md
index 1bad0ee..0827c07 100644
--- a/docs/high-availability.md
+++ b/docs/high-availability.md
@@ -52,7 +52,7 @@ When a network partition disconnects an agent from the leader:
 
 * The leader marks the agent as deactivated and sends its tasks to the LOST 
state. The  [Framework Development Guide](app-framework-development-guide.md) 
describes these various task states.
 
-* Deactivated agents may not re-register with the leader and are told to shut 
down upon any post-deactivation communication.
+* Deactivated agents may not reregister with the leader and are told to shut 
down upon any post-deactivation communication.
 
 ## Implementation Details
 Mesos implements two levels of ZooKeeper leader election abstractions, one in 
`src/zookeeper` and the other in `src/master` (look for 
`contender|detector.hpp|cpp`).

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/docs/maintenance.md
----------------------------------------------------------------------
diff --git a/docs/maintenance.md b/docs/maintenance.md
index 88434e8..67d8b43 100644
--- a/docs/maintenance.md
+++ b/docs/maintenance.md
@@ -275,7 +275,7 @@ told to shutdown.  These agents are removed from the 
master, which means that a
 `TASK_LOST` status update will be sent for every task running on each of those
 agents. The scheduler driver's `slaveLost` callback will also be invoked for
 each of the removed agents. Any agents on machines in maintenance are also
-prevented from re-registering with the master in the future (until maintenance
+prevented from reregistering with the master in the future (until maintenance
 is completed and the machine is brought back up).
 
 ### Completing maintenance

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/docs/monitoring.md
----------------------------------------------------------------------
diff --git a/docs/monitoring.md b/docs/monitoring.md
index 7ad15b4..0fba5ce 100644
--- a/docs/monitoring.md
+++ b/docs/monitoring.md
@@ -737,7 +737,7 @@ messages may indicate that there is a problem with the 
network.
   <td>
   <code>master/recovery_slave_removals</code>
   </td>
-  <td>Number of agents not re-registered during master failover</td>
+  <td>Number of agents not reregistered during master failover</td>
   <td>Counter</td>
 </tr>
 <tr>

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/docs/operator-http-api.md
----------------------------------------------------------------------
diff --git a/docs/operator-http-api.md b/docs/operator-http-api.md
index 64110f0..10dcac8 100644
--- a/docs/operator-http-api.md
+++ b/docs/operator-http-api.md
@@ -2330,7 +2330,7 @@ for all the running tasks. This signal can be used by 
stateful frameworks to
 re-schedule their workloads (volumes, reservations etc.) to other agent
 instances. It is possible that the tasks might still be running if the
 operator's assertion was wrong and the agent was partitioned away from
-the master. The agent would be shutdown when it tries to re-register with the
+the master. The agent would be shutdown when it tries to reregister with the
 master when the partition heals. This call is idempotent.
 
 ```
@@ -2413,7 +2413,7 @@ HEARTBEAT Event (JSON)
 
 ### TASK_ADDED
 
-Sent whenever a task has been added to the master. This can happen either when 
a new task launch is processed by the master or when an agent re-registers with 
a failed over master.
+Sent whenever a task has been added to the master. This can happen either when 
a new task launch is processed by the master or when an agent reregisters with 
a failed over master.
 
 ```
 TASK_ADDED Event (JSON)
@@ -2521,7 +2521,7 @@ FRAMEWORK_ADDED Event (JSON)
 
 ### FRAMEWORK_UPDATED
 
-Sent whenever a framework re-registers with the master upon a disconnection 
(network error) or upon a master failover.
+Sent whenever a framework reregisters with the master upon a disconnection 
(network error) or upon a master failover.
 
 ```
 FRAMEWORK_UPDATED Event (JSON)
@@ -2565,7 +2565,7 @@ FRAMEWORK_UPDATED Event (JSON)
 
 ### FRAMEWORK_REMOVED
 
-Sent whenever a framework is removed. This can happen when a framework is 
explicitly teardown by the operator or if it fails to re-register with the 
master within the failover timeout.
+Sent whenever a framework is removed. This can happen when a framework is 
explicitly teardown by the operator or if it fails to reregister with the 
master within the failover timeout.
 
 ```
 FRAMEWORK_REMOVED Event (JSON)

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/docs/reconciliation.md
----------------------------------------------------------------------
diff --git a/docs/reconciliation.md b/docs/reconciliation.md
index 473e3e2..bfb117c 100644
--- a/docs/reconciliation.md
+++ b/docs/reconciliation.md
@@ -86,7 +86,7 @@ This technique for explicit reconciliation reconciles all 
non-terminal tasks
 until an update is received for each task, using exponential backoff to retry
 tasks that remain unreconciled. Retries are needed because the master 
temporarily
 may not be able to reply for a particular task. For example, during master
-failover the master must re-register all of the agents to rebuild its
+failover the master must reregister all of the agents to rebuild its
 set of known tasks (this process can take minutes for large clusters, and
 is bounded by the `--agent_reregister_timeout` flag on the master).
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/docs/roles.md
----------------------------------------------------------------------
diff --git a/docs/roles.md b/docs/roles.md
index ddea114..d6366dc 100644
--- a/docs/roles.md
+++ b/docs/roles.md
@@ -66,7 +66,7 @@ recommended practice is to only use ACLs to define which 
roles can be used; the
 A framework specifies which roles it would like to subscribe to when it
 subscribes with the master. This is done via the `roles` field in
 `FrameworkInfo`. A framework can also change which roles it is
-subscribed to by re-registering with an updated `FrameworkInfo`.
+subscribed to by reregistering with an updated `FrameworkInfo`.
 
 As a user, you can typically specify which role(s) a framework will
 subscribe to when you start the framework. How to do this depends on the

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/docs/task-state-reasons.md
----------------------------------------------------------------------
diff --git a/docs/task-state-reasons.md b/docs/task-state-reasons.md
index 5f7f8d2..e34e36e 100644
--- a/docs/task-state-reasons.md
+++ b/docs/task-state-reasons.md
@@ -470,7 +470,7 @@ update was sent.
 
 
 <tr><td><code>     REASON_SLAVE_REREGISTERED
-</code></td><td>   The agent on which the task was running has re-registered
+</code></td><td>   The agent on which the task was running has reregistered
                    after being marked unreachable by the master.
 <br/><strong>      Note:
 </strong>          Due to garbage collection of the unreachable and gone agents

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/include/mesos/authorizer/acls.proto
----------------------------------------------------------------------
diff --git a/include/mesos/authorizer/acls.proto 
b/include/mesos/authorizer/acls.proto
index 0862743..8ef3321 100644
--- a/include/mesos/authorizer/acls.proto
+++ b/include/mesos/authorizer/acls.proto
@@ -347,7 +347,7 @@ message ACL {
     required Entity level = 2;
   }
 
-  // Which principals are authorized to register (and re-register) as agents.
+  // Which principals are authorized to register (and reregister) as agents.
   message RegisterAgent {
     // Subjects: Agent principals.
     required Entity principals = 1;

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/include/mesos/executor.hpp
----------------------------------------------------------------------
diff --git a/include/mesos/executor.hpp b/include/mesos/executor.hpp
index 68cba9e..d14c036 100644
--- a/include/mesos/executor.hpp
+++ b/include/mesos/executor.hpp
@@ -87,7 +87,7 @@ public:
       const FrameworkInfo& frameworkInfo,
       const SlaveInfo& slaveInfo) = 0;
 
-  // Invoked when the executor re-registers with a restarted slave.
+  // Invoked when the executor reregisters with a restarted slave.
   virtual void reregistered(
       ExecutorDriver* driver,
       const SlaveInfo& slaveInfo) = 0;

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/include/mesos/master/master.proto
----------------------------------------------------------------------
diff --git a/include/mesos/master/master.proto 
b/include/mesos/master/master.proto
index f40caa2..6622e1b 100644
--- a/include/mesos/master/master.proto
+++ b/include/mesos/master/master.proto
@@ -211,7 +211,7 @@ message Call {
   // NOTE: It is possible that the tasks might still be running
   // if the operator's assertion was wrong and the agent was partitioned
   // away from the master. The agent would be shutdown when it tries to
-  // re-register with the master when the partition heals.
+  // reregister with the master when the partition heals.
   message MarkAgentGone {
     required SlaveID slave_id = 1;
   }
@@ -368,7 +368,7 @@ message Response {
       // If true, this framework was previously subscribed but hasn't
       // yet re-subscribed after a master failover. Recovered frameworks
       // are only reported if one or more agents running a task or
-      // executor for the framework have re-registered after master
+      // executor for the framework have reregistered after master
       // failover.
       required bool recovered = 11;
 
@@ -580,7 +580,7 @@ message Event {
     required Response.GetFrameworks.Framework framework = 1;
   }
 
-  // Forwarded by the master when a framework re-registers with the master
+  // Forwarded by the master when a framework reregisters with the master
   // upon a disconnection (network error) or upon a master failover.
   message FrameworkUpdated {
     required Response.GetFrameworks.Framework framework = 1;
@@ -588,7 +588,7 @@ message Event {
 
   // Forwarded by the master when a framework is removed. This can happen when
   // a framework is explicitly teardown by the operator or if it fails to
-  // re-register with the master within the failover timeout.
+  // reregister with the master within the failover timeout.
   message FrameworkRemoved {
     required FrameworkInfo framework_info = 1;
   }

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/include/mesos/mesos.proto
----------------------------------------------------------------------
diff --git a/include/mesos/mesos.proto b/include/mesos/mesos.proto
index 2c5ae4c..e6ba374 100644
--- a/include/mesos/mesos.proto
+++ b/include/mesos/mesos.proto
@@ -892,7 +892,7 @@ message MasterInfo {
       UNKNOWN = 0;
 
       // The master can handle slaves whose state
-      // changes after re-registering.
+      // changes after reregistering.
       AGENT_UPDATE = 1;
     }
     optional Type type = 1;
@@ -2196,7 +2196,7 @@ enum TaskState {
   //
   // NOTE: This state is not always terminal. For example, tasks might
   // transition from TASK_LOST to TASK_RUNNING or other states when a
-  // partitioned agent re-registers.
+  // partitioned agent reregisters.
   TASK_LOST = 5;     // The task failed but can be rescheduled.
 
   // The following task states are only sent when the framework

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/include/mesos/scheduler.hpp
----------------------------------------------------------------------
diff --git a/include/mesos/scheduler.hpp b/include/mesos/scheduler.hpp
index 423235a..d4cc96e 100644
--- a/include/mesos/scheduler.hpp
+++ b/include/mesos/scheduler.hpp
@@ -81,7 +81,7 @@ public:
       const FrameworkID& frameworkId,
       const MasterInfo& masterInfo) = 0;
 
-  // Invoked when the scheduler re-registers with a newly elected
+  // Invoked when the scheduler reregisters with a newly elected
   // Mesos master. This is only called when the scheduler has
   // previously been registered. MasterInfo containing the updated
   // information about the elected master is provided as an argument.

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/include/mesos/scheduler/scheduler.proto
----------------------------------------------------------------------
diff --git a/include/mesos/scheduler/scheduler.proto 
b/include/mesos/scheduler/scheduler.proto
index 7a90355..339a397 100644
--- a/include/mesos/scheduler/scheduler.proto
+++ b/include/mesos/scheduler/scheduler.proto
@@ -275,8 +275,8 @@ message Call {
 
     // NOTE: 'force' field is not present in v1/scheduler.proto because it is
     // only used by the scheduler driver. The driver sets it to true when the
-    // scheduler re-registers for the first time after a failover. Once
-    // re-registered all subsequent re-registration attempts (e.g., due to ZK
+    // scheduler reregisters for the first time after a failover. Once
+    // reregistered all subsequent re-registration attempts (e.g., due to ZK
     // blip) will have 'force' set to false. This is important because master
     // uses this field to know when it needs to send FrameworkRegisteredMessage
     // vs FrameworkReregisteredMessage.

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/include/mesos/v1/master/master.proto
----------------------------------------------------------------------
diff --git a/include/mesos/v1/master/master.proto 
b/include/mesos/v1/master/master.proto
index 67c9560..6034bd5 100644
--- a/include/mesos/v1/master/master.proto
+++ b/include/mesos/v1/master/master.proto
@@ -209,7 +209,7 @@ message Call {
   // NOTE: It is possible that the tasks might still be running
   // if the operator's assertion was wrong and the agent was partitioned
   // away from the master. The agent would be shutdown when it tries to
-  // re-register with the master when the partition heals.
+  // reregister with the master when the partition heals.
   message MarkAgentGone {
     required AgentID agent_id = 1;
   }
@@ -366,7 +366,7 @@ message Response {
       // If true, this framework was previously subscribed but hasn't
       // yet re-subscribed after a master failover. Recovered frameworks
       // are only reported if one or more agents running a task or
-      // executor for the framework have re-registered after master
+      // executor for the framework have reregistered after master
       // failover.
       required bool recovered = 11;
 
@@ -577,7 +577,7 @@ message Event {
     required Response.GetFrameworks.Framework framework = 1;
   }
 
-  // Forwarded by the master when a framework re-registers with the master
+  // Forwarded by the master when a framework reregisters with the master
   // upon a disconnection (network error) or upon a master failover.
   message FrameworkUpdated {
     required Response.GetFrameworks.Framework framework = 1;
@@ -585,7 +585,7 @@ message Event {
 
   // Forwarded by the master when a framework is removed. This can happen when
   // a framework is explicitly teardown by the operator or if it fails to
-  // re-register with the master within the failover timeout.
+  // reregister with the master within the failover timeout.
   message FrameworkRemoved {
     required FrameworkInfo framework_info = 1;
   }

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/include/mesos/v1/mesos.proto
----------------------------------------------------------------------
diff --git a/include/mesos/v1/mesos.proto b/include/mesos/v1/mesos.proto
index 67080ed..30d4d35 100644
--- a/include/mesos/v1/mesos.proto
+++ b/include/mesos/v1/mesos.proto
@@ -890,7 +890,7 @@ message MasterInfo {
       UNKNOWN = 0;
 
       // The master can handle slaves whose state
-      // changes after re-registering.
+      // changes after reregistering.
       AGENT_UPDATE = 1;
     }
     optional Type type = 1;
@@ -2188,7 +2188,7 @@ enum TaskState {
   //
   // NOTE: This state is not always terminal. For example, tasks might
   // transition from TASK_LOST to TASK_RUNNING or other states when a
-  // partitioned agent re-registers.
+  // partitioned agent reregisters.
   TASK_LOST = 5;     // The task failed but can be rescheduled.
 
   // The following task states are only sent when the framework

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/site/source/blog/2013-10-23-slave-recovery-in-apache-mesos.md
----------------------------------------------------------------------
diff --git a/site/source/blog/2013-10-23-slave-recovery-in-apache-mesos.md 
b/site/source/blog/2013-10-23-slave-recovery-in-apache-mesos.md
index 5b604f5..638d8e6 100644
--- a/site/source/blog/2013-10-23-slave-recovery-in-apache-mesos.md
+++ b/site/source/blog/2013-10-23-slave-recovery-in-apache-mesos.md
@@ -45,7 +45,7 @@ A recoverable slave is critical for running services in 
production on Mesos for
 
 - **Reliable status updates**
 
-    Another benefit of slave checkpointing the status updates is that now 
updates are more reliably delivered to frameworks in the face of failures. 
Before slave recovery if the slave fails at the same time that a master is 
failing over, no TASK_LOST updates for tasks running on the slave were sent to 
the framework. This is partly because the Mesos master is stateless. A failed 
over master reconstructs the cluster state from the information given to it by 
re-registering slaves and frameworks. With slave recovery, status updates and 
tasks are no longer lost when slaves fail. Rather, the slave recovers tasks, 
status updates and reconnects with the running executors. Even if an executor 
does terminate when the slave is down, a recovered slave knows about it from 
its checkpointed state and reliably sends TASK_LOST updates to the framework.
+    Another benefit of slave checkpointing the status updates is that now 
updates are more reliably delivered to frameworks in the face of failures. 
Before slave recovery if the slave fails at the same time that a master is 
failing over, no TASK_LOST updates for tasks running on the slave were sent to 
the framework. This is partly because the Mesos master is stateless. A failed 
over master reconstructs the cluster state from the information given to it by 
reregistering slaves and frameworks. With slave recovery, status updates and 
tasks are no longer lost when slaves fail. Rather, the slave recovers tasks, 
status updates and reconnects with the running executors. Even if an executor 
does terminate when the slave is down, a recovered slave knows about it from 
its checkpointed state and reliably sends TASK_LOST updates to the framework.
 
 For more information about how to enable slave recovery in your cluster, 
please refer to the 
[documentation](https://github.com/apache/mesos/blob/master/docs/Slave-Recovery.md).
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/site/source/blog/2014-06-12-mesos-0-19-0-released.md
----------------------------------------------------------------------
diff --git a/site/source/blog/2014-06-12-mesos-0-19-0-released.md 
b/site/source/blog/2014-06-12-mesos-0-19-0-released.md
index 2d2a3db..8f31bc5 100644
--- a/site/source/blog/2014-06-12-mesos-0-19-0-released.md
+++ b/site/source/blog/2014-06-12-mesos-0-19-0-released.md
@@ -24,9 +24,9 @@ Full release notes are available on 
[JIRA](https://issues.apache.org/jira/secure
 Mesos 0.19.0 introduces the 
["Registrar"](https://cwiki.apache.org/confluence/display/MESOS/Registrar+Design+Document):
 the master now persists the list of registered slaves in a durable replicated 
manner. The previous lack of durable state was an intentional design decision 
that simplified failover and allowed masters to be run and migrated with ease. 
However, the stateless design had issues:
 
 * In the event of a dual failure (slave fails while master is down), no lost 
task notifications are sent. This leads to a task running according to the 
framework but unknown to Mesos.
-* When a new master is elected, we may allow rogue slaves to re-register with 
the master. This leads to tasks running on the slave that are not known to the 
framework.
+* When a new master is elected, we may allow rogue slaves to reregister with 
the master. This leads to tasks running on the slave that are not known to the 
framework.
 
-Persisting the list of registered slaves allows failed over masters to detect 
slaves that do not re-register, and notify frameworks accordingly. It also 
allows us to prevent rogue slaves from re-registering; terminating the rogue 
tasks in the process.
+Persisting the list of registered slaves allows failed over masters to detect 
slaves that do not reregister, and notify frameworks accordingly. It also 
allows us to prevent rogue slaves from reregistering; terminating the rogue 
tasks in the process.
 
 The state is persisted using the [replicated 
log](http://mesos.apache.org/blog/mesos-0-17-0-released-featuring-autorecovery/)
 (available since 0.9.0).
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/site/source/blog/2017-09-18-mesos-1-4-0-released.md
----------------------------------------------------------------------
diff --git a/site/source/blog/2017-09-18-mesos-1-4-0-released.md 
b/site/source/blog/2017-09-18-mesos-1-4-0-released.md
index fcdc2e4..1f6077c 100644
--- a/site/source/blog/2017-09-18-mesos-1-4-0-released.md
+++ b/site/source/blog/2017-09-18-mesos-1-4-0-released.md
@@ -18,7 +18,7 @@ The latest Mesos release, 1.4.0, is now available for 
[download](/downloads). Th
   not have wanted it.
 
   * [MESOS-6223](https://issues.apache.org/jira/browse/MESOS-6223) -
-  With partition awareness, the agents are now allowed to re-register after 
they
+  With partition awareness, the agents are now allowed to reregister after they
   have been marked Unreachable. Thus, they can recover their agent ID after a
   host reboot. See docs/upgrades.md for details.
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/site/source/blog/2017-12-07-performance-working-group-progress-report.md
----------------------------------------------------------------------
diff --git 
a/site/source/blog/2017-12-07-performance-working-group-progress-report.md 
b/site/source/blog/2017-12-07-performance-working-group-progress-report.md
index b7f5a87..0f59515 100644
--- a/site/source/blog/2017-12-07-performance-working-group-progress-report.md
+++ b/site/source/blog/2017-12-07-performance-working-group-progress-report.md
@@ -26,7 +26,7 @@ Before we dive into the master failover improvements, I would 
like to recognize
 
 ## Master Failover Time-To-Completion
 
-Our first area of focus was to improve the time it takes for a master failover 
to complete, where completion is defined as all of the agents successfully 
re-registering. Mesos is architected to use a centralized master with standby 
masters that participate in a quorum for high availability. For scalability 
reasons, the leading master stores the state of the cluster in-memory. During a 
master failover, the leading master needs to therefore re-build the in-memory 
state from all of the agents that re-register. During this time, the master is 
available to process other requests, but will be exposing only partial state to 
API consumers.
+Our first area of focus was to improve the time it takes for a master failover 
to complete, where completion is defined as all of the agents successfully 
reregistering. Mesos is architected to use a centralized master with standby 
masters that participate in a quorum for high availability. For scalability 
reasons, the leading master stores the state of the cluster in-memory. During a 
master failover, the leading master needs to therefore re-build the in-memory 
state from all of the agents that reregister. During this time, the master is 
available to process other requests, but will be exposing only partial state to 
API consumers.
 
 The rebuilding of the master’s in-memory state can be expensive for larger 
clusters, and so the focus of this effort was to improve the efficiency of 
this. Improvements were made via several areas, and only the highest-impact 
changes are listed below:
 
@@ -52,9 +52,9 @@ With these previous enhancements in place, we were able to 
eliminate many of the
 
 ### Benchmark and Results
 
-We wrote a synthetic benchmark to simulate a master failover. This benchmark 
prepares all the messages that would be sent to the master by the agents that 
need to re-register:
+We wrote a synthetic benchmark to simulate a master failover. This benchmark 
prepares all the messages that would be sent to the master by the agents that 
need to reregister:
 
-* The benchmark uses synthetic agents in that they are just an actor that 
knows how to re-register with the master.
+* The benchmark uses synthetic agents in that they are just an actor that 
knows how to reregister with the master.
 * Each "agent" will send a configurable number of active and completed tasks 
belonging to a configurable number of active and completed frameworks.
 * Each task has 10 small labels to introduce metadata overhead.
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/exec/exec.cpp
----------------------------------------------------------------------
diff --git a/src/exec/exec.cpp b/src/exec/exec.cpp
index 0c76a3f..65a671d 100644
--- a/src/exec/exec.cpp
+++ b/src/exec/exec.cpp
@@ -251,12 +251,12 @@ protected:
   void reregistered(const SlaveID& slaveId, const SlaveInfo& slaveInfo)
   {
     if (aborted.load()) {
-      VLOG(1) << "Ignoring re-registered message from agent " << slaveId
+      VLOG(1) << "Ignoring reregistered message from agent " << slaveId
               << " because the driver is aborted!";
       return;
     }
 
-    LOG(INFO) << "Executor re-registered on agent " << slaveId;
+    LOG(INFO) << "Executor reregistered on agent " << slaveId;
 
     connected = true;
     connection = id::UUID::random();

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/java/src/org/apache/mesos/Executor.java
----------------------------------------------------------------------
diff --git a/src/java/src/org/apache/mesos/Executor.java 
b/src/java/src/org/apache/mesos/Executor.java
index 078c0c7..4851b5e 100644
--- a/src/java/src/org/apache/mesos/Executor.java
+++ b/src/java/src/org/apache/mesos/Executor.java
@@ -61,9 +61,9 @@ public interface Executor {
                   SlaveInfo slaveInfo);
 
   /**
-   * Invoked when the executor re-registers with a restarted slave.
+   * Invoked when the executor reregisters with a restarted slave.
    *
-   * @param driver      The executor driver that was re-registered with the
+   * @param driver      The executor driver that was reregistered with the
    *                    Mesos master.
    * @param slaveInfo   Describes the slave that will be used to launch
    *                    the tasks for this executor.

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/java/src/org/apache/mesos/Scheduler.java
----------------------------------------------------------------------
diff --git a/src/java/src/org/apache/mesos/Scheduler.java 
b/src/java/src/org/apache/mesos/Scheduler.java
index cb5a658..4e5d743 100644
--- a/src/java/src/org/apache/mesos/Scheduler.java
+++ b/src/java/src/org/apache/mesos/Scheduler.java
@@ -57,12 +57,12 @@ public interface Scheduler {
                   MasterInfo masterInfo);
 
   /**
-   * Invoked when the scheduler re-registers with a newly elected Mesos master.
+   * Invoked when the scheduler reregisters with a newly elected Mesos master.
    * This is only called when the scheduler has previously been registered.
    * MasterInfo containing the updated information about the elected master
    * is provided as an argument.
    *
-   * @param driver      The driver that was re-registered.
+   * @param driver      The driver that was reregistered.
    * @param masterInfo  The updated information about the elected master.
    *
    * @see SchedulerDriver

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/master/allocator/mesos/hierarchical.cpp
----------------------------------------------------------------------
diff --git a/src/master/allocator/mesos/hierarchical.cpp 
b/src/master/allocator/mesos/hierarchical.cpp
index e0ab836..5d30d1d 100644
--- a/src/master/allocator/mesos/hierarchical.cpp
+++ b/src/master/allocator/mesos/hierarchical.cpp
@@ -200,7 +200,7 @@ void HierarchicalAllocatorProcess::recover(
   CHECK(_expectedAgentCount >= 0);
 
   // If there is no quota, recovery is a no-op. Otherwise, we need
-  // to delay allocations while agents are re-registering because
+  // to delay allocations while agents are reregistering because
   // otherwise we perform allocations on a partial view of resources!
   // We would consequently perform unnecessary allocations to satisfy
   // quota constraints, which can over-allocate non-revocable resources
@@ -643,7 +643,7 @@ void HierarchicalAllocatorProcess::updateSlave(
 
     // We unconditionally overwrite the old domain and hostname: Even though
     // the master places some restrictions on this (i.e. agents are not allowed
-    // to re-register with a different hostname) inside the allocator it
+    // to reregister with a different hostname) inside the allocator it
     // doesn't matter, as the algorithm will work correctly either way.
     slave.info = info;
   }

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/master/constants.hpp
----------------------------------------------------------------------
diff --git a/src/master/constants.hpp b/src/master/constants.hpp
index 17092ea..b31e5f0 100644
--- a/src/master/constants.hpp
+++ b/src/master/constants.hpp
@@ -63,9 +63,9 @@ constexpr Duration DEFAULT_AGENT_PING_TIMEOUT = Seconds(15);
 constexpr size_t DEFAULT_MAX_AGENT_PING_TIMEOUTS = 5;
 
 // The minimum timeout that can be used by a newly elected leader to
-// allow re-registration of slaves. Any slaves that do not re-register
+// allow re-registration of slaves. Any slaves that do not reregister
 // within this timeout will be marked unreachable; if/when the agent
-// re-registers, non-partition-aware tasks running on the agent will
+// reregisters, non-partition-aware tasks running on the agent will
 // be terminated.
 constexpr Duration MIN_AGENT_REREGISTER_TIMEOUT = Minutes(10);
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/master/flags.cpp
----------------------------------------------------------------------
diff --git a/src/master/flags.cpp b/src/master/flags.cpp
index 2f4aa69..dbb35be 100644
--- a/src/master/flags.cpp
+++ b/src/master/flags.cpp
@@ -124,11 +124,11 @@ mesos::internal::master::Flags::Flags()
   add(&Flags::agent_reregister_timeout,
       "agent_reregister_timeout",
       flags::DeprecatedName("slave_reregister_timeout"),
-      "The timeout within which an agent is expected to re-register.\n"
-      "Agents re-register when they become disconnected from the master\n"
+      "The timeout within which an agent is expected to reregister.\n"
+      "Agents reregister when they become disconnected from the master\n"
       "or when a new master is elected as the leader. Agents that do not\n"
-      "re-register within the timeout will be marked unreachable in the\n"
-      "registry; if/when the agent re-registers with the master, any\n"
+      "reregister within the timeout will be marked unreachable in the\n"
+      "registry; if/when the agent reregisters with the master, any\n"
       "non-partition-aware tasks running on the agent will be terminated.\n"
       "NOTE: This value has to be at least " +
         stringify(MIN_AGENT_REREGISTER_TIMEOUT) + ".",

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/master/master.cpp
----------------------------------------------------------------------
diff --git a/src/master/master.cpp b/src/master/master.cpp
index e666b66..381be8e 100644
--- a/src/master/master.cpp
+++ b/src/master/master.cpp
@@ -468,7 +468,7 @@ void Master::initialize()
                  << "**************************************************";
   }
 
-  // NOTE: We enforce a minimum slave re-register timeout because the
+  // NOTE: We enforce a minimum slave reregister timeout because the
   // slave bounds its (re-)registration retries based on the minimum.
   if (flags.agent_reregister_timeout < MIN_AGENT_REREGISTER_TIMEOUT) {
     EXIT(EXIT_FAILURE)
@@ -1338,14 +1338,14 @@ void Master::exited(const UPID& pid)
       // If the master -> agent socket breaks, we expect that either
       // (a) the agent will fail to respond to pings and be marked
       // unreachable, or (b) the agent will receive a ping, notice the
-      // master thinks it is disconnected, and then re-register. There
+      // master thinks it is disconnected, and then reregister. There
       // is a third possibility: if the agent restarts but hangs
       // during agent recovery, it will respond to pings but never
-      // attempt to re-register (MESOS-6286).
+      // attempt to reregister (MESOS-6286).
       //
       // To handle this case, we expect that an agent whose socket has
-      // broken will re-register within `agent_reregister_timeout`. If
-      // the agent doesn't re-register, it is marked unreachable.
+      // broken will reregister within `agent_reregister_timeout`. If
+      // the agent doesn't reregister, it is marked unreachable.
       slave->reregistrationTimer =
         delay(flags.agent_reregister_timeout,
               self(),
@@ -1366,7 +1366,7 @@ void Master::agentReregisterTimeout(const SlaveID& 
slaveId)
 {
   Slave* slave = slaves.registered.get(slaveId);
 
-  // The slave might have been removed or re-registered concurrently
+  // The slave might have been removed or reregistered concurrently
   // with the timeout expiring.
   if (slave == nullptr || slave->connected) {
     return;
@@ -1379,7 +1379,7 @@ void Master::agentReregisterTimeout(const SlaveID& 
slaveId)
   if (slaves.limiter.isSome()) {
       LOG(INFO) << "Scheduling removal of agent "
                 << *slave
-                << "; did not re-register within "
+                << "; did not reregister within "
                 << flags.agent_reregister_timeout << " after disconnecting";
 
       acquire = slaves.limiter.get()->acquire();
@@ -1396,7 +1396,7 @@ Nothing Master::_agentReregisterTimeout(const SlaveID& 
slaveId)
 {
   Slave* slave = slaves.registered.get(slaveId);
 
-  // The slave might have been removed or re-registered while we were
+  // The slave might have been removed or reregistered while we were
   // waiting to acquire the rate limit.
   if (slave == nullptr || slave->connected) {
     ++metrics->slave_unreachable_canceled;
@@ -1408,7 +1408,7 @@ Nothing Master::_agentReregisterTimeout(const SlaveID& 
slaveId)
   markUnreachable(
       slave->info,
       false,
-      "agent did not re-register within " +
+      "agent did not reregister within " +
       stringify(flags.agent_reregister_timeout) +
       " after disconnecting");
 
@@ -1726,7 +1726,7 @@ Future<Nothing> Master::_recover(const Registry& registry)
   // Set up a timer for age-based registry GC.
   scheduleRegistryGc();
 
-  // Set up a timeout for slaves to re-register.
+  // Set up a timeout for slaves to reregister.
   slaves.recoveredTimer =
     delay(flags.agent_reregister_timeout,
           self(),
@@ -1805,7 +1805,7 @@ Future<Nothing> Master::_recover(const Registry& registry)
   LOG(INFO) << "Recovered " << registry.slaves().slaves().size() << " agents"
             << " from the registry (" << Bytes(registry.ByteSize()) << ")"
             << "; allowing " << flags.agent_reregister_timeout
-            << " for agents to re-register";
+            << " for agents to reregister";
 
   return Nothing();
 }
@@ -1975,7 +1975,7 @@ void Master::recoveredSlavesTimeout(const Registry& 
registry)
       << flags.agent_reregister_timeout
       << " there were " << slaves.recovered.size()
       << " (" << removalPercentage * 100 << "%) agents recovered from the"
-      << " registry that did not re-register: \n"
+      << " registry that did not reregister: \n"
       << stringify(slaves.recovered.keys()) << "\n "
       << " The configured removal limit is " << limit * 100 << "%. Please"
       << " investigate or increase this limit to proceed further";
@@ -1986,7 +1986,7 @@ void Master::recoveredSlavesTimeout(const Registry& 
registry)
   foreach (const Registry::Slave& slave, registry.slaves().slaves()) {
     // The slave is removed from `recovered` when it completes the
     // re-registration process. If the slave is in `reregistering`, it
-    // has started but not yet finished re-registering. In either
+    // has started but not yet finished reregistering. In either
     // case, we don't want to try to remove it.
     if (!slaves.recovered.contains(slave.info().id()) ||
         slaves.reregistering.contains(slave.info().id())) {
@@ -1998,7 +1998,7 @@ void Master::recoveredSlavesTimeout(const Registry& 
registry)
     if (slaves.limiter.isSome()) {
       LOG(INFO) << "Scheduling removal of agent "
                 << slave.info().id() << " (" << slave.info().hostname() << ")"
-                << "; did not re-register within "
+                << "; did not reregister within "
                 << flags.agent_reregister_timeout << " after master failover";
 
       acquire = slaves.limiter.get()->acquire();
@@ -2009,10 +2009,10 @@ void Master::recoveredSlavesTimeout(const Registry& 
registry)
     // TODO(bmahler): Cancelation currently occurs within by returning
     // early from `markUnreachable` *without* the "discarder" having
     // discarded the rate limit token. This approach means that if
-    // agents re-register while many of the marking unreachable
+    // agents reregister while many of the marking unreachable
     // operations are in progress, the rate that we mark unreachable
     // will "slow down" rather than stay constant. We should instead
-    // discard the rate limit token when the agent re-registers and
+    // discard the rate limit token when the agent reregisters and
     // handle the discard here. See MESOS-8386.
     acquire
       .onFailed(lambda::bind(fail, failure, lambda::_1))
@@ -2021,7 +2021,7 @@ void Master::recoveredSlavesTimeout(const Registry& 
registry)
                   &Self::markUnreachable,
                   slave.info(),
                   true,
-                  "did not re-register within"
+                  "did not reregister within"
                   " " + stringify(flags.agent_reregister_timeout) +
                   " after master failover"))
       .then(defer(self(), [=](bool marked) {
@@ -2690,8 +2690,8 @@ void Master::_subscribe(
   Framework* framework = getFramework(frameworkInfo.id());
 
   if (framework == nullptr) {
-    // The framework has not yet re-registered after master failover.
-    // Furthermore, no agents have re-registered running one of this
+    // The framework has not yet reregistered after master failover.
+    // Furthermore, no agents have reregistered running one of this
     // framework's tasks. Reconstruct a `Framework` object from the
     // supplied `FrameworkInfo`.
     recoverFramework(frameworkInfo, suppressedRoles);
@@ -2711,7 +2711,7 @@ void Master::_subscribe(
     // Always failover the old framework connection. See MESOS-4712 for 
details.
     failoverFramework(framework, http);
   } else {
-    // The framework has not yet re-registered after master failover.
+    // The framework has not yet reregistered after master failover.
     Try<Nothing> activate = activateRecoveredFramework(
         framework, frameworkInfo, None(), http, suppressedRoles);
 
@@ -3009,8 +3009,8 @@ void Master::_subscribe(
   Framework* framework = getFramework(frameworkInfo.id());
 
   if (framework == nullptr) {
-    // The framework has not yet re-registered after master failover.
-    // Furthermore, no agents have re-registered running one of this
+    // The framework has not yet reregistered after master failover.
+    // Furthermore, no agents have reregistered running one of this
     // framework's tasks. Reconstruct a `Framework` object from the
     // supplied `FrameworkInfo`.
     recoverFramework(frameworkInfo, suppressedRoles);
@@ -3117,7 +3117,7 @@ void Master::_subscribe(
       return;
     }
   } else {
-    // The framework has not yet re-registered after master failover.
+    // The framework has not yet reregistered after master failover.
     Try<Nothing> activate = activateRecoveredFramework(
         framework, frameworkInfo, from, None(), suppressedRoles);
 
@@ -5700,7 +5700,7 @@ void Master::kill(Framework* framework, const 
scheduler::Call::Kill& kill)
   slave->killedTasks.put(framework->id(), taskId);
 
   // NOTE: This task will be properly reconciled when the disconnected slave
-  // re-registers with the master.
+  // reregisters with the master.
   // We send the KillTaskMessage even if we have already sent one, just in case
   // the previous one was dropped by the network but it didn't trigger a slave
   // re-registration (and hence reconciliation).
@@ -5721,7 +5721,7 @@ void Master::kill(Framework* framework, const 
scheduler::Call::Kill& kill)
     LOG(WARNING) << "Cannot kill task " << taskId
                  << " of framework " << *framework
                  << " because the agent " << *slave << " is disconnected."
-                 << " Kill will be retried if the agent re-registers";
+                 << " Kill will be retried if the agent reregisters";
   }
 }
 
@@ -6357,7 +6357,7 @@ void Master::reregisterSlave(
   if (flags.authenticate_agents && !authenticated.contains(from)) {
     // This could happen if another authentication request came
     // through before we are here or if a slave tried to
-    // re-register without authentication.
+    // reregister without authentication.
     LOG(WARNING) << "Refusing re-registration of agent at " << from
                  << " because it is not authenticated";
     ShutdownMessage message;
@@ -6374,7 +6374,7 @@ void Master::reregisterSlave(
   const SlaveInfo& slaveInfo = reregisterSlaveMessage.slave();
   if (slaves.reregistering.contains(slaveInfo.id())) {
     LOG(INFO)
-      << "Ignoring re-register agent message from agent "
+      << "Ignoring reregister agent message from agent "
       << slaveInfo.id() << " at " << from << " ("
       << slaveInfo.hostname() << ") as re-registration is already in progress";
     return;
@@ -6382,7 +6382,7 @@ void Master::reregisterSlave(
 
   if (slaves.markingGone.contains(slaveInfo.id())) {
     LOG(INFO)
-      << "Ignoring re-register agent message from agent "
+      << "Ignoring reregister agent message from agent "
       << slaveInfo.id() << " at " << from << " ("
       << slaveInfo.hostname() << ") as a gone operation is already in 
progress";
     return;
@@ -6408,7 +6408,7 @@ void Master::reregisterSlave(
     return;
   }
 
-  LOG(INFO) << "Received re-register agent message from agent "
+  LOG(INFO) << "Received reregister agent message from agent "
             << slaveInfo.id() << " at " << from << " ("
             << slaveInfo.hostname() << ")";
 
@@ -6462,7 +6462,7 @@ void Master::_reregisterSlave(
     authorizationError = "Authorization failure: " + authorized.failure();
   } else if (!authorized.get()) {
     authorizationError =
-      "Not authorized to re-register agent providing resources "
+      "Not authorized to reregister agent providing resources "
       "'" + stringify(Resources(slaveInfo.resources())) + "' " +
       (principal.isSome()
        ? "with principal '" + stringify(principal.get()) + "'"
@@ -6484,7 +6484,7 @@ void Master::_reregisterSlave(
 
   if (slaves.markingGone.contains(slaveInfo.id())) {
     LOG(INFO)
-      << "Ignoring re-register agent message from agent "
+      << "Ignoring reregister agent message from agent "
       << slaveInfo.id() << " at " << pid << " ("
       << slaveInfo.hostname() << ") as a gone operation is already in 
progress";
 
@@ -6511,7 +6511,7 @@ void Master::_reregisterSlave(
   machineId.set_hostname(slaveInfo.hostname());
   machineId.set_ip(stringify(pid.address.ip));
 
-  // Slaves are not allowed to re-register while the machine they are on is in
+  // Slaves are not allowed to reregister while the machine they are on is in
   // 'DOWN` mode.
   if (machines.contains(machineId) &&
       machines[machineId].info.mode() == MachineInfo::DOWN) {
@@ -6552,7 +6552,7 @@ void Master::_reregisterSlave(
 
   // If the agent is configured with a domain but the master is not,
   // we can't determine whether the agent is remote. To be safe, we
-  // don't allow the agent to re-register. We don't shutdown the agent
+  // don't allow the agent to reregister. We don't shutdown the agent
   // so that any tasks on the agent can continue to run.
   //
   // TODO(neilc): Consider sending a warning to agent (MESOS-7615).
@@ -6582,7 +6582,7 @@ void Master::_reregisterSlave(
     CHECK(!slaves.recovered.contains(slaveInfo.id()));
 
     // NOTE: This handles the case where a slave tries to
-    // re-register with an existing master (e.g. because of a
+    // reregister with an existing master (e.g. because of a
     // spurious Zookeeper session expiration or after the slave
     // recovers after a restart).
     // For now, we assume this slave is not nefarious (eventually
@@ -6591,7 +6591,7 @@ void Master::_reregisterSlave(
     VLOG(1) << "Agent is already marked as registered: " << slaveInfo.id()
             << " at " << pid << " (" << slaveInfo.hostname() << ")";
 
-    // We don't allow re-registering this way with a different IP or
+    // We don't allow reregistering this way with a different IP or
     // hostname. This is because maintenance is scheduled at the
     // machine level; so we would need to re-validate the slave's
     // unavailability if the machine it is running on changed.
@@ -6599,13 +6599,13 @@ void Master::_reregisterSlave(
         slave->info.hostname() != slaveInfo.hostname()) {
       LOG(WARNING) << "Agent " << slaveInfo.id() << " at " << pid
                    << " (" << slaveInfo.hostname() << ") attempted to "
-                   << "re-register with different IP / hostname; expected "
+                   << "reregister with different IP / hostname; expected "
                    << slave->pid.address.ip << " (" << slave->info.hostname()
                    << ") shutting it down";
 
       ShutdownMessage message;
       message.set_message(
-          "Agent attempted to re-register with different IP / hostname");
+          "Agent attempted to reregister with different IP / hostname");
 
       send(pid, message);
 
@@ -6629,7 +6629,7 @@ void Master::_reregisterSlave(
             lambda::_1));
     }
   } else if (slaves.recovered.contains(slaveInfo.id())) {
-    // The agent likely is re-registering after a master failover as it
+    // The agent likely is reregistering after a master failover as it
     // is in the list recovered from the registry.
     VLOG(1) << "Re-admitting recovered agent " << slaveInfo.id()
             << " at " << pid << "(" << slaveInfo.hostname() << ")";
@@ -6693,7 +6693,7 @@ void Master::__reregisterSlave(
 
   if (slaves.markingGone.contains(slaveInfo.id())) {
     LOG(INFO)
-      << "Ignoring re-register agent message from agent "
+      << "Ignoring reregister agent message from agent "
       << slaveInfo.id() << " at " << pid << " ("
       << slaveInfo.hostname() << ") as a gone operation is already in 
progress";
 
@@ -6777,7 +6777,7 @@ void Master::__reregisterSlave(
   machineId.set_ip(stringify(pid.address.ip));
 
   // For easy lookup, first determine the set of FrameworkIDs on the
-  // re-registering agent that are partition-aware.
+  // reregistering agent that are partition-aware.
   hashset<FrameworkID> partitionAwareFrameworks;
 
   foreach (const FrameworkInfo& framework,
@@ -6809,7 +6809,7 @@ void Master::__reregisterSlave(
 
       const string message = slaves.unreachable.contains(slaveInfo.id())
           ? "Unreachable agent re-reregistered"
-          : "Unknown agent re-registered";
+          : "Unknown agent reregistered";
 
       const StatusUpdate& update = protobuf::createStatusUpdate(
           task.framework_id(),
@@ -6907,7 +6907,7 @@ void Master::__reregisterSlave(
            reregisterSlaveMessage.frameworks()) {
     if (isCompletedFramework(framework.id())) {
       LOG(INFO) << "Shutting down framework " << framework.id()
-                << " at re-registered agent " << *slave
+                << " at reregistered agent " << *slave
                 << " because the framework has been shutdown at the master";
 
       ShutdownFrameworkMessage message;
@@ -6944,7 +6944,7 @@ void Master::___reregisterSlave(
 
   if (slaves.markingGone.contains(slaveInfo.id())) {
     LOG(INFO)
-      << "Ignoring re-register agent message from agent "
+      << "Ignoring reregister agent message from agent "
       << slaveInfo.id() << " at " << pid << " ("
       << slaveInfo.hostname() << ") as a gone operation is already in 
progress";
 
@@ -7097,7 +7097,7 @@ void Master::___reregisterSlave(
       // the agent is downgraded before the partition heals.
       //
       // TODO(neilc): It would probably be better to prevent the agent
-      // from re-registering in this scenario.
+      // from reregistering in this scenario.
       Try<Nothing> result = downgradeResources(&message);
       if (result.isError()) {
         LOG(WARNING) << "Not sending updated checkpointed resources "
@@ -7157,7 +7157,7 @@ void Master::updateSlaveFrameworks(
       }
 
       LOG(INFO) << "Recovering framework " << frameworkInfo.id()
-                << " from re-registering agent " << *slave;
+                << " from reregistering agent " << *slave;
 
       recoverFramework(frameworkInfo, {});
     }
@@ -7862,7 +7862,7 @@ void Master::statusUpdate(StatusUpdate update, const 
UPID& pid)
 
   Framework* framework = getFramework(update.framework_id());
 
-  // A framework might not have re-registered upon a master failover or
+  // A framework might not have reregistered upon a master failover or
   // got disconnected.
   if (framework != nullptr && framework->connected()) {
     forward(update, pid, framework);
@@ -7879,7 +7879,7 @@ void Master::statusUpdate(StatusUpdate update, const 
UPID& pid)
   if (task == nullptr) {
     // TODO(neilc): We might see status updates for non-partition
     // aware tasks running on a partitioned agent that has
-    // re-registered with the master. The master marks such tasks
+    // reregistered with the master. The master marks such tasks
     // completed when the agent partitions; it will shutdown the
     // framework when the agent-reregisters, but we may see a number
     // of status updates before the framework is shutdown.
@@ -8147,7 +8147,7 @@ Future<bool> Master::markUnreachable(
   if (duringMasterFailover && !slaves.recovered.contains(slave.id())) {
     LOG(INFO) << "Skipping transition of agent"
               << " " << slave.id() << " (" << slave.hostname() << ")"
-              << " to unreachable because it re-registered in the interim";
+              << " to unreachable because it reregistered in the interim";
     return false;
   }
 
@@ -8168,7 +8168,7 @@ Future<bool> Master::markUnreachable(
   if (slaves.reregistering.contains(slave.id())) {
     LOG(INFO) << "Skipping transition of agent"
               << " " << slave.id() << " (" << slave.hostname() << ")"
-              << " to unreachable because it is re-registering";
+              << " to unreachable because it is reregistering";
     return false;
   }
 
@@ -8440,7 +8440,7 @@ void Master::_reconcileTasks(
   //
   // For case (3), if the slave ID is not provided, we err on the
   // side of caution and do not reply if there are *any* recovered
-  // slaves that haven't re-registered, since the task could reside
+  // slaves that haven't reregistered, since the task could reside
   // on one of these slaves.
   //
   // For cases (4), (5), (6) and (7) TASK_LOST is sent instead if the
@@ -8501,7 +8501,7 @@ void Master::_reconcileTasks(
                 << (slaveId.isSome() ?
                       "agent " + stringify(slaveId.get()) + " has" :
                       "some agents have")
-                << " not yet re-registered with the master";
+                << " not yet reregistered with the master";
     } else if (slaveId.isSome() && slaves.registered.contains(slaveId.get())) {
       // (4) Task is unknown, slave is registered: TASK_GONE. If the
       // framework does not have the PARTITION_AWARE capability, send
@@ -8614,7 +8614,7 @@ void Master::frameworkFailoverTimeout(const FrameworkID& 
frameworkId,
 
   if (framework != nullptr && !framework->connected()) {
     // If the re-registration time has not changed, then the framework
-    // has not re-registered within the failover timeout.
+    // has not reregistered within the failover timeout.
     if (framework->reregisteredTime == reregisteredTime) {
       LOG(INFO) << "Framework failover timeout, removing framework "
                 << *framework;
@@ -8921,17 +8921,17 @@ void Master::authenticate(const UPID& from, const UPID& 
pid)
   // 3. Client restarted.
   //   3.1. We are here after receiving 'exited()' from old client.
   //        This is safe because the client will be first marked as
-  //        disconnected and then when it re-registers it will be
+  //        disconnected and then when it reregisters it will be
   //        marked as connected.
   //
   //  3.2. We are here before receiving 'exited()' from old client.
   //       This is tricky only if the PID of the client doesn't change
   //       after restart; true for slave but not for framework.
   //       If the PID doesn't change the master might mark the client
-  //       disconnected *after* the client re-registers.
+  //       disconnected *after* the client reregisters.
   //       This is safe because the client (slave) will be informed
   //       about this discrepancy via ping messages so that it can
-  //       re-register.
+  //       reregister.
 
   authenticated.erase(pid);
 
@@ -9172,7 +9172,7 @@ void Master::reconcileKnownSlave(
                 frameworks.completed) {
     if (slaveTasks.contains(framework->id())) {
       LOG(WARNING) << "Agent " << *slave
-                   << " re-registered with completed framework " << *framework
+                   << " reregistered with completed framework " << *framework
                    << ". Shutting down the framework on the agent";
 
       ShutdownFrameworkMessage message;
@@ -9337,8 +9337,8 @@ Try<Nothing> Master::activateRecoveredFramework(
 
   if (pid.isSome()) {
     // TODO(bmahler): We have to send a registered message here for
-    // the re-registering framework, per the API contract. Send
-    // re-register here per MESOS-786; requires deprecation or it
+    // the reregistering framework, per the API contract. Send
+    // reregister here per MESOS-786; requires deprecation or it
     // will break frameworks.
     FrameworkRegisteredMessage message;
     message.mutable_framework_id()->MergeFrom(framework->id());
@@ -9524,7 +9524,7 @@ void Master::removeFramework(Framework* framework)
   foreachvalue (Task* task, utils::copy(framework->tasks)) {
     Slave* slave = slaves.registered.get(task->slave_id());
 
-    // Since we only find out about tasks when the slave re-registers,
+    // Since we only find out about tasks when the slave reregisters,
     // it must be the case that the slave exists!
     CHECK(slave != nullptr)
       << "Unknown agent " << task->slave_id()
@@ -9570,7 +9570,7 @@ void Master::removeFramework(Framework* framework)
 
     // TODO(neilc): Per comment above, using TASK_KILLED here is not
     // ideal. It would be better to use TASK_UNREACHABLE here and only
-    // transition it to a terminal state when the agent re-registers
+    // transition it to a terminal state when the agent reregisters
     // and the task is shutdown (MESOS-6608).
     const StatusUpdate& update = protobuf::createStatusUpdate(
         task->framework_id(),
@@ -9747,8 +9747,8 @@ void Master::addSlave(
   foreachkey (const FrameworkID& frameworkId, slave->executors) {
     Framework* framework = getFramework(frameworkId);
 
-    // If the framework has not re-registered yet and this is the
-    // first agent to re-register that is running the framework, we
+    // If the framework has not reregistered yet and this is the
+    // first agent to reregister that is running the framework, we
     // skip adding the framework's executors here. Instead, the
     // framework will be recovered in `__reregisterSlave` and its
     // executors will be added by `recoverFramework`.
@@ -9766,8 +9766,8 @@ void Master::addSlave(
   foreachkey (const FrameworkID& frameworkId, slave->tasks) {
     Framework* framework = getFramework(frameworkId);
 
-    // If the framework has not re-registered yet and this is the
-    // first agent to re-register that is running the framework, we
+    // If the framework has not reregistered yet and this is the
+    // first agent to reregister that is running the framework, we
     // skip adding the framework's tasks here. Instead, the framework
     // will be recovered in `__reregisterSlave` and its tasks will be
     // added by `recoverFramework`.
@@ -9800,7 +9800,7 @@ void Master::addSlave(
                 << " that ran on agent " << *slave;
         framework->addCompletedTask(std::move(task));
       } else {
-        // The framework might not be re-registered yet.
+        // The framework might not be reregistered yet.
         //
         // TODO(vinod): Revisit these semantics when we store frameworks'
         // information in the registrar.
@@ -10314,7 +10314,7 @@ void Master::removeTask(Task* task, bool unreachable)
 
   // Remove from framework.
   Framework* framework = getFramework(task->framework_id());
-  if (framework != nullptr) { // A framework might not be re-registered yet.
+  if (framework != nullptr) { // A framework might not be reregistered yet.
     framework->removeTask(task, unreachable);
   }
 
@@ -10343,7 +10343,7 @@ void Master::removeExecutor(
       frameworkId, slave->id, executor.resources(), None());
 
   Framework* framework = getFramework(frameworkId);
-  if (framework != nullptr) { // The framework might not be re-registered yet.
+  if (framework != nullptr) { // The framework might not be reregistered yet.
     framework->removeExecutor(slave->id, executorId);
   }
 
@@ -10653,7 +10653,7 @@ void Master::_apply(
       // the agent is downgraded before the partition heals.
       //
       // TODO(neilc): It would probably be better to prevent the agent
-      // from re-registering in this scenario.
+      // from reregistering in this scenario.
       Try<Nothing> result = downgradeResources(&message);
       if (result.isError()) {
         LOG(WARNING) << "Not sending updated checkpointed resources "
@@ -11732,7 +11732,7 @@ Try<Nothing> Slave::update(
   // There is a short window here where `totalResources` can have an old value,
   // but it should be relatively short because the agent will send
   // an `UpdateSlaveMessage` with the new total resources immediately after
-  // re-registering in this case.
+  // reregistering in this case.
   totalResources = resources.get();
 
   if (resourceVersion.isSome()) {

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/master/master.hpp
----------------------------------------------------------------------
diff --git a/src/master/master.hpp b/src/master/master.hpp
index c9c8a96..a97fd08 100644
--- a/src/master/master.hpp
+++ b/src/master/master.hpp
@@ -209,10 +209,10 @@ Slave(Master* const _master,
   bool active;
 
   // Timer for marking slaves unreachable that become disconnected and
-  // don't re-register. This timeout is larger than the slave
+  // don't reregister. This timeout is larger than the slave
   // observer's timeout, so typically the slave observer will be the
   // one to mark such slaves unreachable; this timer is a backup for
-  // when a slave responds to pings but does not re-register (e.g.,
+  // when a slave responds to pings but does not reregister (e.g.,
   // because agent recovery has hung).
   Option<process::Timer> reregistrationTimer;
 
@@ -240,7 +240,7 @@ Slave(Master* const _master,
   hashmap<FrameworkID, hashmap<TaskID, Task*>> tasks;
 
   // Tasks that were asked to kill by frameworks.
-  // This is used for reconciliation when the slave re-registers.
+  // This is used for reconciliation when the slave reregisters.
   multihashmap<FrameworkID, TaskID> killedTasks;
 
   // Pending operations or terminal operations that have
@@ -652,7 +652,7 @@ protected:
       const std::vector<TaskStatus>& statuses);
 
   // When a slave that was previously registered with this master
-  // re-registers, we need to reconcile the master's view of the
+  // reregisters, we need to reconcile the master's view of the
   // slave's tasks and executors.  This function also sends the
   // `SlaveReregisteredMessage`.
   void reconcileKnownSlave(
@@ -667,7 +667,7 @@ protected:
 
   // Recover a framework from its `FrameworkInfo`. This happens after
   // master failover, when an agent running one of the framework's
-  // tasks re-registers or when the framework itself re-registers,
+  // tasks reregisters or when the framework itself reregisters,
   // whichever happens first. The result of this function is a
   // registered, inactive framework with state `RECOVERED`.
   void recoverFramework(
@@ -676,7 +676,7 @@ protected:
 
   // Transition a framework from `RECOVERED` to `CONNECTED` state and
   // activate it. This happens at most once after master failover, the
-  // first time that the framework re-registers with the new master.
+  // first time that the framework reregisters with the new master.
   // Exactly one of `newPid` or `http` must be provided.
   Try<Nothing> activateRecoveredFramework(
       Framework* framework,
@@ -1798,13 +1798,13 @@ private:
     Slaves() : removed(MAX_REMOVED_SLAVES) {}
 
     // Imposes a time limit for slaves that we recover from the
-    // registry to re-register with the master.
+    // registry to reregister with the master.
     Option<process::Timer> recoveredTimer;
 
     // Slaves that have been recovered from the registrar after master
     // failover. Slaves are removed from this collection when they
-    // either re-register with the master or are marked unreachable
-    // because they do not re-register before `recoveredTimer` fires.
+    // either reregister with the master or are marked unreachable
+    // because they do not reregister before `recoveredTimer` fires.
     // We must not answer questions related to these slaves (e.g.,
     // during task reconciliation) until we determine their fate
     // because their are in this transitioning state.
@@ -2170,8 +2170,8 @@ struct Framework
   enum State
   {
     // Framework has never connected to this master. This implies the
-    // master failed over and the framework has not yet re-registered,
-    // but some framework state has been recovered from re-registering
+    // master failed over and the framework has not yet reregistered,
+    // but some framework state has been recovered from reregistering
     // agents that are running tasks for the framework.
     RECOVERED,
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/python/executor/src/mesos/executor/proxy_executor.cpp
----------------------------------------------------------------------
diff --git a/src/python/executor/src/mesos/executor/proxy_executor.cpp 
b/src/python/executor/src/mesos/executor/proxy_executor.cpp
index 2462ccb..6e1491a 100644
--- a/src/python/executor/src/mesos/executor/proxy_executor.cpp
+++ b/src/python/executor/src/mesos/executor/proxy_executor.cpp
@@ -101,7 +101,7 @@ void ProxyExecutor::reregistered(ExecutorDriver* driver,
                             impl,
                             slaveInfoObj);
   if (res == nullptr) {
-    cerr << "Failed to call executor re-registered" << endl;
+    cerr << "Failed to call executor reregistered" << endl;
     goto cleanup;
   }
 

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/python/interface/src/mesos/interface/__init__.py
----------------------------------------------------------------------
diff --git a/src/python/interface/src/mesos/interface/__init__.py 
b/src/python/interface/src/mesos/interface/__init__.py
index 048eb64..f9642a0 100644
--- a/src/python/interface/src/mesos/interface/__init__.py
+++ b/src/python/interface/src/mesos/interface/__init__.py
@@ -47,7 +47,7 @@ class Scheduler(object):
 
   def reregistered(self, driver, masterInfo):
     """
-      Invoked when the scheduler re-registers with a newly elected Mesos
+      Invoked when the scheduler reregisters with a newly elected Mesos
       master.  This is only called when the scheduler has previously been
       registered.  masterInfo contains information about the newly elected
       master.
@@ -292,7 +292,7 @@ class Executor(object):
 
   def reregistered(self, driver, slaveInfo):
     """
-      Invoked when the executor re-registers with a restarted slave.
+      Invoked when the executor reregisters with a restarted slave.
     """
 
   def disconnected(self, driver):

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/sched/sched.cpp
----------------------------------------------------------------------
diff --git a/src/slave/constants.hpp b/src/slave/constants.hpp
index b79c084..f1fc2bf 100644
--- a/src/slave/constants.hpp
+++ b/src/slave/constants.hpp
@@ -35,11 +35,11 @@ namespace slave {
 constexpr Duration EXECUTOR_REGISTRATION_TIMEOUT = Minutes(1);
 constexpr Duration EXECUTOR_REREGISTRATION_TIMEOUT = Seconds(2);
 
-// The maximum timeout within which an executor can re-register.
+// The maximum timeout within which an executor can reregister.
 // Note that this value has to be << 'MIN_AGENT_REREGISTER_TIMEOUT'
 // declared in 'master/constants.hpp'; since agent recovery will only
 // complete after this timeout has elapsed, this ensures that the
-// agent can re-register with the master before it is marked
+// agent can reregister with the master before it is marked
 // unreachable and its tasks are transitioned to TASK_UNREACHABLE or
 // TASK_LOST.
 constexpr Duration MAX_EXECUTOR_REREGISTRATION_TIMEOUT = Seconds(15);

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/slave/containerizer/mesos/isolators/filesystem/linux.cpp
----------------------------------------------------------------------
diff --git a/src/slave/containerizer/mesos/isolators/filesystem/linux.cpp 
b/src/slave/containerizer/mesos/isolators/filesystem/linux.cpp
index f1d377e..6ee2499 100644
--- a/src/slave/containerizer/mesos/isolators/filesystem/linux.cpp
+++ b/src/slave/containerizer/mesos/isolators/filesystem/linux.cpp
@@ -540,7 +540,7 @@ Future<Nothing> LinuxFilesystemIsolatorProcess::update(
       // target existed:
       // 1. This is possible because 'info->resources' will be reset
       //    when slave restarts and recovers. When the slave calls
-      //    'containerizer->update' after the executor re-registers,
+      //    'containerizer->update' after the executor reregisters,
       //    we'll try to re-mount all the already mounted volumes.
       // 2. There may be multiple references to the persistent
       //    volume's mount target. E.g., a host volume and a

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/slave/containerizer/mesos/isolators/filesystem/posix.cpp
----------------------------------------------------------------------
diff --git a/src/slave/containerizer/mesos/isolators/filesystem/posix.cpp 
b/src/slave/containerizer/mesos/isolators/filesystem/posix.cpp
index df240bc..9ac41af 100644
--- a/src/slave/containerizer/mesos/isolators/filesystem/posix.cpp
+++ b/src/slave/containerizer/mesos/isolators/filesystem/posix.cpp
@@ -229,7 +229,7 @@ Future<Nothing> PosixFilesystemIsolatorProcess::update(
     if (os::exists(link)) {
       // NOTE: This is possible because 'info->resources' will be
       // reset when slave restarts and recovers. When the slave calls
-      // 'containerizer->update' after the executor re-registers,
+      // 'containerizer->update' after the executor reregisters,
       // we'll try to relink all the already symlinked volumes.
       Result<string> realpath = os::realpath(link);
       if (!realpath.isSome()) {

Reply via email to
diff --git a/src/sched/sched.cpp b/src/sched/sched.cpp
index 81aa0d7..b682d1b 100644
--- a/src/sched/sched.cpp
+++ b/src/sched/sched.cpp
@@ -769,26 +769,26 @@ protected:
       const MasterInfo& masterInfo)
   {
     if (!running.load()) {
-      VLOG(1) << "Ignoring framework re-registered message because "
+      VLOG(1) << "Ignoring framework reregistered message because "
               << "the driver is not running!";
       return;
     }
 
     if (connected) {
-      VLOG(1) << "Ignoring framework re-registered message because "
+      VLOG(1) << "Ignoring framework reregistered message because "
               << "the driver is already connected!";
       return;
     }
 
     if (master.isNone() || from != master->pid()) {
       LOG(WARNING)
-        << "Ignoring framework re-registered message because it was sent "
+        << "Ignoring framework reregistered message because it was sent "
         << "from '" << from << "' instead of the leading master '"
         << (master.isSome() ? UPID(master->pid()) : UPID()) << "'";
       return;
     }
 
-    LOG(INFO) << "Framework re-registered with " << frameworkId;
+    LOG(INFO) << "Framework reregistered with " << frameworkId;
 
     CHECK(framework.id() == frameworkId);
 
@@ -1517,7 +1517,7 @@ protected:
     VLOG(2) << "Asked to send framework message to agent "
             << slaveId;
 
     // TODO(benh): After a scheduler has re-registered it won't have
     // any saved slave PIDs, maybe it makes sense to try and save each
     // PID that this scheduler tries to send a message to? Or we can
     // just wait for them to recollect as new offers come in and get

http://git-wip-us.apache.org/repos/asf/mesos/blob/a4e9695f/src/slave/constants.hpp
----------------------------------------------------------------------
@@ -1517,7 +1517,7 @@ protected:
             << slaveId;
 
-    // TODO(benh): After a scheduler has re-registered it won't have
+    // TODO(benh): After a scheduler has reregistered it won't have
     // any saved slave PIDs, maybe it makes sense to try and save each
     // PID that this scheduler tries to send a message to? Or we can